"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalSourceRegistry = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
class LocalSourceRegistry {
    constructor(logger, manifestPackage) {
        this._multiFlatDict = {};
        this._flatDict = {};
        this._logger = logger.sublogger('LocalSourceRegistry');
        this._manifestPackage = manifestPackage;
    }
    get manifests() {
        return the_lodash_1.default.values(this._flatDict);
    }
    add(manifest) {
        const key = the_lodash_1.default.stableStringify(manifest.id);
        this._flatDict[key] = manifest;
        if (!this._multiFlatDict[key]) {
            this._multiFlatDict[key] = [];
        }
        this._multiFlatDict[key].push(manifest);
    }
    extractDuplicateGroups() {
        const duplicateGroups = [];
        for (const key of the_lodash_1.default.keys(this._multiFlatDict)) {
            const manifests = this._multiFlatDict[key];
            if (manifests.length > 1) {
                duplicateGroups.push(manifests);
            }
        }
        return duplicateGroups;
    }
    enforceDuplicateCheck() {
        const duplicateGroups = this.extractDuplicateGroups();
        for (const manifests of duplicateGroups) {
            for (const manifest of manifests) {
                const message = 'Manifest is defined in multiple sources.';
                manifest.reportError(message);
            }
        }
    }
    cleanupDuplicates() {
        const duplicateGroups = this.extractDuplicateGroups();
        for (const manifests of duplicateGroups) {
            for (const manifest of the_lodash_1.default.dropRight(manifests, 1)) {
                const message = 'Manifest is duplicate and is skipped.';
                manifest.reportWarning(message);
                // manifest.isSkipped = true;
            }
            {
                const message = 'Duplicate manifests found.';
                the_lodash_1.default.last(manifests).reportWarning(message);
            }
        }
    }
}
exports.LocalSourceRegistry = LocalSourceRegistry;
//# sourceMappingURL=local-source-registry.js.map